@@ -16,14 +16,14 @@ OC.L10N.register(
     "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
     "Download" : "Hämta",
     "Close" : "Stäng",
+    "Internal server error!" : "Internt serverfel!",
+    "Unknown error!" : "Okänt fel!",
     "Web address" : "Webbadress",
     "Please check your data/nextcloud.log file for additional information!" : "Kontrollera din data/nextcloud.log-fil för ytterligare information!",
     "No folder" : "Ingen mapp",
     "Folder name" : "Mappnamn",
     "Username" : "Användarnamn",
     "Password" : "Lösenord",
-    "Internal server error!" : "Internt serverfel!",
-    "Unknown error!" : "Okänt fel!",
     "Feed exists already!" : "Flödet finns redan!",
     "New folder" : "Ny mapp",
     "Folder exists already!" : "Katalogen finns redan",
@@ -31,6 +31,8 @@ OC.L10N.register(
     "Credentials" : "Inloggningsuppgifter",
     "Auto discover Feed" : "Upptäck flöde automatiskt",
     "Subscribe" : "Prenumerera",
+    "Successfully updated news configuration" : "Nyhetskonfigurationen har uppdaterats",
+    "Unable to update news config" : "Kunde inte uppdatera nyhetskonfigurationen",
     "Last job execution ran {relativeTime}. Something seems wrong." : "Senaste jobbexekveringen kördes {relativeTime}. Något verkar vara fel.",
     "Last job ran {relativeTime}." : "Senaste jobbet kördes {relativeTime}.",
     "Maximum read count per feed" : "Maximalt läsantal per flöde",
@@ -38,8 +40,6 @@ OC.L10N.register(
     "Feed fetcher timeout" : "Timeout för flödes-hämtare",
     "Explore Service URL" : "Utforska tjänstwebbadress",
     "Update interval" : "Uppdateringsintervall",
-    "Successfully updated news configuration" : "Nyhetskonfigurationen har uppdaterats",
-    "Unable to update news config" : "Kunde inte uppdatera nyhetskonfigurationen",
     "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
     "Disable this if you use a custom updater." : "Slå av detta om du anväder en egen uppdateringsprocess.",
     "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definierar den maximala mängden artiklar som kan läsas per flöde som inte kommer att raderas av rensningsjobbet; om gamla artiklar dyker upp igen efter att ha lästs, öka detta värde; negativa värden som -1 kommer att stänga av denna funktion.",
@@ -59,21 +59,6 @@ OC.L10N.register(
     "Share" : "Dela",
     "Share with" : "Dela med",
     "Share with {num} users" : "Dela med {num} användare",
-    "Mark read" : "Markera som läst",
-    "All articles" : "Alla artiklar",
-    "Starred" : "Stjärnmärkt",
-    "Has feeds with errors!" : "Har flöden med fel!",
-    "Explore" : "Utforska",
-    "Settings" : "Inställningar",
-    "Keyboard shortcuts" : "Tangentbordsgenvägar",
-    "Article feed information" : "Artikelflödesinformation",
-    "Display mode" : "Visningsläge",
-    "Split mode" : "Delat läge",
-    "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
-    "Show all articles" : "Visa alla artiklar",
-    "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
-    "Disable automatic refresh" : "Inaktivera automatisk uppdatering",
-    "Abonnements (OPML)" : "Prenumerationer (OPML)",
     "Default" : "Förvald",
     "Compact" : "Kompakt",
     "Screenreader" : "Skärmläsare",
@@ -87,10 +72,26 @@ OC.L10N.register(
     "Error retrieving the opml file" : "Det gick inte att hämta opml-filen",
     "Rename Folder" : "Byt namn på mapp",
     "Are you sure you want to delete?" : "Är du säker på att du vill ta bort?",
+    "Mark read" : "Markera som läst",
+    "All articles" : "Alla artiklar",
+    "Starred" : "Stjärnmärkt",
+    "Has feeds with errors!" : "Har flöden med fel!",
+    "Explore" : "Utforska",
+    "Settings" : "Inställningar",
+    "Documentation" : "Dokumentation",
+    "Keyboard shortcuts" : "Tangentbordsgenvägar",
+    "Article feed information" : "Artikelflödesinformation",
+    "Display mode" : "Visningsläge",
+    "Split mode" : "Delat läge",
+    "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
+    "Show all articles" : "Visa alla artiklar",
+    "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
+    "Disable automatic refresh" : "Inaktivera automatisk uppdatering",
+    "Abonnements (OPML)" : "Prenumerationer (OPML)",
     "Rename" : "Byt namn",
     "Delete" : "Ta bort",
-    "Open Feed URL" : "Öppna flödes-URL",
     "Rename Feed" : "Döp om Feed",
+    "Open Feed URL" : "Öppna flödes-URL",
     "Unpin from top" : "Ta bort från toppen",
     "Pin to top" : "Fäst i toppen",
     "Newest first" : "Nyaste först",
@@ -100,6 +101,10 @@ OC.L10N.register(
     "Disable full text" : "Avaktivera fulltext",
     "Unread updated" : "Markera som oläst",
     "Ignore updated" : "Ignorera uppdaterad",
+    "Previous Item" : "Föregående objekt",
+    "Previous" : "Föregående",
+    "Next Item" : "Nästa objekt",
+    "Next" : "Nästa",
     "Share within Instance" : "Dela inom instans",
     "Toggle star article" : "Växla stjärnmärkning av artiklar",
     "Mark unread" : "Markera som oläst",
@@ -110,16 +115,17 @@ OC.L10N.register(
     "Play audio" : "Spela ljud",
     "Download audio" : "Hämta ljud",
     "Download video" : "Hämta video",
-    "Open website" : "Öppna webbplats",
-    "Keep article unread" : "Behåll artikel oläst",
-    "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
-    "Remove keep article unread" : "Ta bort behåll artikel oläst",
     "{num} seconds" : "{num} sekunder",
     "{num} minutes ago" : "{num} minuter sedan",
     "{num} hours ago" : "{num} timmar sedan",
     "{num} days ago" : "{num} dagar sedan",
     "{num} months ago" : "{num} månader sedan",
     "{num} years ago" : "{num} år sedan",
+    "Open website" : "Öppna webbplats",
+    "Keep article unread" : "Behåll artikel oläst",
+    "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
+    "Remove keep article unread" : "Ta bort behåll artikel oläst",
+    "Not available" : "Inte tillgänglig",
     "Last update" : "Senaste uppdatering",
     "Time when the feed was last downloaded" : "Tidpunkt då flödet senast laddades ned",
     "Next update" : "Nästa uppdatering",
@@ -130,7 +136,6 @@ OC.L10N.register(
     "Error Count" : "Antal fel",
     "Number of errors that have occurred since the last successful feed update" : "Antal fel som har inträffat sedan den senaste framgångsrika flödesuppdateringen",
     "Title" : "Titel",
-    "Not available" : "Inte tillgänglig",
     "Keyboard shortcut" : "Tangentbordsgenvägar",
     "Action" : "Ågärd",
     "Jump to next article" : "Hoppa till nästa artikel",
@@ -194,7 +199,6 @@ OC.L10N.register(
     "Unread/Starred Articles" : "Olästa/Stjärnmärkta artiklar",
     "Error when importing: file does not contain valid JSON" : "Fel vid import: filen innehåller inte giltig JSON",
     "Help" : "Hjälp",
-    "Documentation" : "Dokumentation",
     "Report a bug" : "Rapportera ett problem"
 },
 "nplurals=2; plural=(n != 1);");
