@@ -9,14 +9,24 @@ OC.L10N.register(
     "Password" : "Password",
     "New folder" : "New folder",
     "Credentials" : "Hisob ma'lumotlari",
+    "Subscribe" : "Obuna boʻlish",
     "Move" : "Move",
+    "Share" : "Ulashish",
     "Settings" : "Settings",
+    "Documentation" : "Hujjatlar",
     "Rename" : "Rename",
     "Delete" : "Delete",
+    "Previous" : "Oldingi",
+    "Not available" : "Mavjud emas",
+    "Title" : "Sarlavha",
     "right" : "right",
     "left" : "left",
     "Refresh" : "Refresh",
+    "Description" : "Tavsif",
+    "Create" : "Yaratish",
     "Dismiss" : "Dismiss",
+    "Import" : "Import",
+    "Export" : "Eksport",
     "Help" : "Help"
 },
 "nplurals=1; plural=0;");
